@@ -7,12 +7,20 @@ const project = new cdk.JsiiProject({
   projenrcTs: true,
   repositoryUrl: 'https://github.com/lazinessdevs/lazy-constructs.git',
 
+  codeCov: true,
+
   release: true,
 
   publishToPypi: {
     distName: 'lazy-constructs',
     module: 'lazy_constructs',
   },
+  publishToMaven: {
+    javaPackage: 'com.lazinessdevs.lazyconstructs',
+    mavenArtifactId: 'lazy-constructs',
+    mavenGroupId: 'com.lazinessdevs',
+    mavenEndpoint: 'https://s01.oss.sonatype.org',
+  },
   publishTasks: true,
 
   peerDeps: [
